@@ -1,13 +1,5 @@
 context("pp_query")
 
-test_that("get error if API key is null", {
-  
-  expect_error(pp_query('115/bills/hr21.json',API = 'congress', version='v1', myAPI_Key = NULL))
-  
-  expect_error(pp_query('2018/races/MI/house/11.json', API='campaign-finance',version='v1', myAPI_Key = NULL))
-  
-})
-
 test_that("get error if API not support", {
   expect_error(pp_query('2018/races/MI/house/11.json', API='myAPI',version='v1', myAPI_Key = "PLgSaGES7ne8SLcWnwxAL2DeddgwuSLK4lQD34vj"), "API not supported.")
 })
